@@ -3,8 +3,9 @@ from typing import Optional, Set, List
 
 from cmem.cmempy.dp.proxy.graph import get_graphs_list
 
+from cmem_plugin_base.dataintegration.context import PluginContext
 from cmem_plugin_base.dataintegration.types import StringParameterType, Autocompletion
-from cmem_plugin_base.dataintegration.utils import setup_cmempy_super_user_access
+from cmem_plugin_base.dataintegration.utils import setup_cmempy_user_access
 
 
 class GraphParameterType(StringParameterType):
@@ -45,10 +46,9 @@ class GraphParameterType(StringParameterType):
                 "http://rdfs.org/ns/void#Dataset",
             }
 
-    def autocomplete(
-        self, query_terms: list[str], project_id: Optional[str] = None
-    ) -> list[Autocompletion]:
-        setup_cmempy_super_user_access()
+    def autocomplete(self, query_terms: list[str],
+                     context: PluginContext) -> list[Autocompletion]:
+        setup_cmempy_user_access(context=context.user)
         graphs = get_graphs_list()
         result = []
         for _ in graphs:
